@@ -319,7 +319,7 @@ where
 /// Combinator for repeating encoding of `E::Item`.
 ///
 /// This is created by calling `EncodeExt::repeat` method.
-#[derive(Debug, Default)]
+#[derive(Debug)]
 pub struct Repeat<E, I> {
     inner: E,
     items: Option<I>,
@@ -374,6 +374,11 @@ where
         self.items.is_none()
     }
 }
+impl<E: Default, I> Default for Repeat<E, I> {
+    fn default() -> Self {
+        Self::new(E::default())
+    }
+}
 
 /// An alias of `Omittable`.
 #[deprecated(since = "0.2.16", note = "please use `Omittable` instead")]
